@@ -1,4 +1,4 @@
-from .types import t_asset, copy_button, t_add, t_update
+from .types import t_asset, copy_button, t_add, t_update, t_delete
 from .runner.env_var import n_env
 from .manager import Manager
 import os
@@ -27,14 +27,14 @@ class Assets:
         if raw:
             json_filtered = []
             for item in json_data:
-                if item["type"] == self.role:
+                if item["type"] == self.role and item["status"] != t_delete:
                     print(item)
                     json_filtered.append(item)
                 return json_filtered
         else:
             for item in json_data:
                 kind = None
-                if item["type"] == self.role:
+                if item["type"] == self.role and item["status"] != t_delete:
                     kind = f"gettable with this url {self.manager.proxy_url('assets', item['value'])}"
                     path = (
                         item["path"]
