@@ -1,15 +1,13 @@
-from .types import t_delete, t_job, t_add, t_env, error_busy, error_reject
+from .types import t_delete, t_job, t_env, error_busy, error_reject
 from IPython.core.display import display, HTML
 from .runner.proxy import encode_proxy_url
 from .runner.env_var import n_env
-import ipywidgets as widgets
 import pandas as pd
 import traceback
 import ipykernel
 import requests
 import base64
 import copy
-import uuid
 import os
 
 
@@ -32,7 +30,7 @@ class Manager:
         self.set_runner_mode()
 
     def is_production(self):
-        return False if self.notebook_path() else True
+        return True if n_env.current.get("env") == "RUNNER" else False
 
     def set_runner_mode(self):
         try:
@@ -105,7 +103,7 @@ class Manager:
 
     def running_notebooks(self):
         try:
-            base_url = f"{n_env.hub_api}/user/{n_env.user}/api/sessions"
+            base_url = f"{n_env.user_url}/api/sessions"
             req = requests.get(url=base_url, headers=self.headers)
             req.raise_for_status()
             sessions = req.json()
@@ -132,36 +130,6 @@ class Manager:
         else:
             return self.notebook_path()
 
-    def copy_clipboard(self, text):
-        uid = uuid.uuid4().hex
-        js = """<script>
-        function copyToClipboard_{uid}(text) {
-            const dummy = document.createElement("textarea");
-            document.body.appendChild(dummy);
-            dummy.value = text;
-            dummy.select();
-            document.execCommand("copy");
-            document.body.removeChild(dummy);
-        }
-        </script>"""
-        js = js.replace("{uid}", uid)
-        display(HTML(js))
-        js2 = f"<script>copyToClipboard_{uid}(`" + text + "`);</script>"
-        display(HTML(js2))
-
-    def copy_url(self, text):
-        button = widgets.Button(description="Copy URL", button_style="primary")
-        output = widgets.Output()
-
-        def on_button_clicked(b):
-            with output:
-                self.copy_clipboard(text)
-                html_div = '<div id="pasting_to_clipboard">✅ Copied !</div>'
-                display(HTML(html_div))
-
-        button.on_click(on_button_clicked)
-        display(button, output)
-
     def proxy_url(self, endpoint, token=None):
         public_url = encode_proxy_url(endpoint)
         if token:
@@ -240,7 +208,7 @@ class Manager:
             raise
 
     def get_file(self, path=None, mode=None, histo=None):
-        if not path and self.is_production():
+        if self.is_production():
             print("No get_prod done you are in production\n")
             return
         current_file = self.get_path(path)
@@ -289,7 +257,7 @@ class Manager:
             dev_path = obj.get("path")
             new_obj["path"] = self.get_path(dev_path)
             new_obj["file"] = self.__open_file(dev_path)
-            new_obj["status"] = t_add
+            # new_obj["status"] = t_add
             try:
                 if debug:
                     print(f'{new_obj["status"]} ==> {new_obj}')
