@@ -20,6 +20,7 @@ from .controllers.logs import LogsController
 from sanic_openapi import swagger_blueprint
 from .controllers.env import EnvController
 from .notifications import Notifications
+from naas.onboarding import init_onborading
 from .proxy import escape_kubernet
 from .scheduler import Scheduler
 from .notebooks import Notebooks
@@ -41,7 +42,7 @@ import nest_asyncio
 asyncio.set_event_loop_policy(None)
 nest_asyncio.apply()
 
-__version__ = "0.32.1"
+__version__ = "0.33.1"
 
 
 class Runner:
@@ -73,6 +74,7 @@ class Runner:
         )
 
     async def initialize_before_start(self, app, loop):
+        init_onborading()
         if self.__jobs is None:
             self.__jobs = Jobs(self.__logger)
             self.__secret = Secret(self.__logger)
